# Generated by roxygen2: do not edit by hand

export(add_island_cols)
export(aruba)
export(is_sids)
export(is_small_island)
export(is_snij)
export(island_coords)
export(island_distance)
export(island_lookup)
export(small_islands)
importFrom(countrycode,countrycode)
